@@ -1,4 +1,4 @@
-#! /usr/bin/env python
+# ! /usr/bin/env python
 """
 Model Management and simulation objects.
 """
@@ -247,7 +247,7 @@ class simulate:
                     if int(o.geocode) == j[0] or self.seed[0][0] == "all":
                         #self.Say("%s infected person(s) arrived at %s"%(j[2],o.sitename))
                         inits[j[1].lower()] += j[2]
-                        o.createModel( self.modtype, self.modelName, v=values, bi=inits, bp=parms)
+                        o.createModel(self.modtype, self.modelName, v=values, bi=inits, bp=parms)
                     else:
                         o.createModel(self.modtype, self.modelName, v=values, bi=inits, bp=parms)
             else:
@@ -445,16 +445,16 @@ class simulate:
         site_list = self.g.site_list
         site_dict = self.g.site_dict
         # Temporarily disabled animation output due to the sheer size of the kmz files
-        #        if  len(site_dict)*len(site_dict.values()[0].ts)<10000: #Only reasonably sized animations
-        #            for i, v in enumerate(site_dict.values()[0].vnames):
-        #                ka = epigdal.AnimatedKML(os.path.join(self.outdir, 'Data.kml'), extrude = True)
-        #                data = [(str(site.geocode), t, p[i]) for site in site_dict.itervalues() for t, p in enumerate(site.ts)]
-        #                ka.add_data(data)
-        #                ka.save(v+'_animation')
-        #                self.Say(v+'_animation')
-        #                del ka
-        #        else:
-        #            self.Say("Simulation too large to export as kml.")
+        if len(site_dict) * len(site_dict.values()[0].ts) < 20000:  # Only reasonably sized animations
+            for i, v in enumerate(site_dict.values()[0].vnames):
+                ka = epigdal.AnimatedKML(os.path.join(self.outdir, 'Data.kml'), extrude=True)
+                data = [(str(site.geocode), t, p[i]) for site in site_dict.itervalues() for t, p in enumerate(site.ts)]
+                ka.add_data(data)
+                ka.save(v + '_animation')
+                self.Say(v + '_animation')
+                del ka
+        else:
+            self.Say("Simulation too large to export as kml.")
 
         self.Say("Done creating KML files!")
 
@@ -749,7 +749,8 @@ class simulate:
                 con = sqlite3.connect("Epigrass.sqlite")
                 os.chdir(self.dir)
             # Define number of variables to be stored
-            nvar = len(self.g.site_dict.values()[0].ts[-1]) + 4  # state variables,  plus coords, plus incidence, plus infected arrivals.
+            nvar = len(self.g.site_dict.values()[0].ts[
+                -1]) + 4  # state variables,  plus coords, plus incidence, plus infected arrivals.
             str1 = '`%s` FLOAT(9),' * nvar  # nvar variables in the table
             str1lite = '%s REAL,' * nvar  # nvar variables in the SQLite table
             varnames = ['lat', 'longit'] + list(self.g.site_dict.values()[0].vnames) + ['incidence'] + ['Arrivals']
@@ -790,9 +791,10 @@ class simulate:
                 inc = site.incidence
                 thist = site.thetahist
                 t = 0
-                for i in ts:
+                for incid, flow in zip(inc, thist):
                     tstep = str(t)
-                    nvalues.append(tuple([geoc, tstep, name] + [lat, long] + list(i) + [inc[t]] + [float(thist[t])]))
+                    flow = float(thist[t])
+                    nvalues.append(tuple([geoc, tstep, name] + [lat, long] + list(ts[t]) + [incid] + [flow]))
                     t += 1
             Cursor.executemany(sql2, nvalues)
             #Creating a table for edge data
@@ -1119,8 +1121,7 @@ def upload_model(args):
     passwd = getpass("Enter your Epigrass Web password:")
     S = simulate(fname=args.epg[0], backend=args.backend)
 
-
-app_url = "http://app.epigrass.net/simulations/view/new/"  # creating the app id
+    app_url = "http://app.epigrass.net/simulations/view/new/"  # creating the app id
     r = requests.get(app_url, auth=(username, passwd))
     fields = {'epg': (S.modelName, open(S.fname, 'rb'), 'text/plain')}
     if os.path.exists(os.path.join(S.outdir, 'data.json')):
